summaryrefslogtreecommitdiffstats
path: root/redhat/applications/kaffeine/kaffeine-3.5.13-fix_typos_branding_tqt.patch
blob: 144e4bb1c7d0a7abe7f499ab77889c23c60c5049 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
commit 0e3d0ed603c6c8065fdcb77bc79b59a768fc6a5b
Author: Darrell Anderson <humanreadable@yahoo.com>
Date:   1333649519 -0500

    Fix typos, branding, and inadvertent tqt changes.

diff --git a/kaffeine/src/input/dvb/dvbpanel.cpp b/kaffeine/src/input/dvb/dvbpanel.cpp
index 969b62b..bbc4e32 100644
--- a/kaffeine/src/input/dvb/dvbpanel.cpp
+++ b/kaffeine/src/input/dvb/dvbpanel.cpp
@@ -1065,8 +1065,7 @@ void DvbPanel::setConfig()
 		connect( d, TQT_SIGNAL(isRecording(bool)), this, TQT_SLOT(setRecordLed(bool)) );
 		connect( d, TQT_SIGNAL(playDvb()), this, TQT_SLOT(pipeOpened()) );
 	}
-// 	fifoName = TQDir::homeDirPath()+"/.kaxtv.ts";
-	fifoName = KGlobal::dirs()->saveLocation("tmp")+"/.kaxtv.ts";
+	fifoName = KGlobal::dirs()->saveLocation("tmp")+".kaxtv.ts";
 	TQFile f( fifoName );
 	if ( f.exists() )
 		f.remove();
@@ -1074,8 +1073,7 @@ void DvbPanel::setConfig()
 		perror( fifoName.latin1() );
 		fifoName = "";
 	}
-// 	fifoName1 = TQDir::homeDirPath()+"/.kaxtv1.ts";
-	fifoName1 = KGlobal::dirs()->saveLocation("tmp")+"/.kaxtv1.ts";
+	fifoName1 = KGlobal::dirs()->saveLocation("tmp")+".kaxtv1.ts";
 	TQFile f1( fifoName1 );
 	if ( f1.exists() )
 		f1.remove();
diff --git a/kaffeine/src/input/dvb/lib/libdvben50221/en50221_app_auth.h b/kaffeine/src/input/dvb/lib/libdvben50221/en50221_app_auth.h
index 2b1d2e7..57b9254 100644
--- a/kaffeine/src/input/dvb/lib/libdvben50221/en50221_app_auth.h
+++ b/kaffeine/src/input/dvb/lib/libdvben50221/en50221_app_auth.h
@@ -42,7 +42,7 @@ extern "C" {
  * @param session_number Session number concerned.
  * @param auth_protocol_id Auth protocol id.
  * @param auth_data Data for the request.
- * @param auth_data_lenghth Number of bytes.
+ * @param auth_data_length Number of bytes.
  * @return 0 on success, -1 on failure.
  */
 typedef int (*en50221_app_auth_request_callback) (void *arg,
diff --git a/kaffeine/src/input/dvb/lib/libdvben50221/en50221_app_teletext.h b/kaffeine/src/input/dvb/lib/libdvben50221/en50221_app_teletext.h
index b5b85f1..ce6ef42 100644
--- a/kaffeine/src/input/dvb/lib/libdvben50221/en50221_app_teletext.h
+++ b/kaffeine/src/input/dvb/lib/libdvben50221/en50221_app_teletext.h
@@ -42,7 +42,7 @@ extern "C" {
  * @param slot_id Slot id concerned.
  * @param session_number Session number concerned.
  * @param teletext_data Data for the request.
- * @param teletext_data_lenghth Number of bytes.
+ * @param teletext_data_length Number of bytes.
  * @return 0 on success, -1 on failure.
  */
 typedef int (*en50221_app_teletext_callback) (void *arg,
diff --git a/kaffeine/src/kmultitabbar.cpp b/kaffeine/src/kmultitabbar.cpp
index 8d85e01..e8148a7 100644
--- a/kaffeine/src/kmultitabbar.cpp
+++ b/kaffeine/src/kmultitabbar.cpp
@@ -347,7 +347,7 @@ int KMultiTabBarInternal::appendTab(const TQPixmap &pic ,int id,const TQString&
 	tab->installEventFilter(this);
 	tab->showActiveTabText(m_showActiveTabTexts);
 
-	if (m_style==KMultiTabBar::KONTQSBC)
+	if (m_style==KMultiTabBar::KONQSBC)
 	{
 		if (m_expandedTabSize<tab->neededSize()) {
 			m_expandedTabSize=tab->neededSize();
@@ -570,7 +570,7 @@ void KMultiTabBarTab::setState(bool b)
 void KMultiTabBarTab::updateState()
 {
 
-	if (m_style!=KMultiTabBar::KONTQSBC) {
+	if (m_style!=KMultiTabBar::KONQSBC) {
 		if ((m_style==KMultiTabBar::KDEV3) || (m_style==KMultiTabBar::KDEV3ICON) || (down)) {
 			TQPushButton::setText(m_text);
 		} else {
@@ -626,7 +626,7 @@ void KMultiTabBarTab::drawButtonLabel(TQPainter *p) {
 }
 void KMultiTabBarTab::drawButton(TQPainter *paint)
 {
-	if (m_style!=KMultiTabBar::KONTQSBC) drawButtonStyled(paint);
+	if (m_style!=KMultiTabBar::KONQSBC) drawButtonStyled(paint);
 	else  drawButtonClassic(paint);
 }
 
@@ -858,7 +858,7 @@ KMultiTabBar::KMultiTabBar(KMultiTabBarMode bm, TQWidget *parent,const char *nam
 	setPosition((bm==KMultiTabBar::Vertical)?KMultiTabBar::Right:KMultiTabBar::Bottom);
 	setStyle(VSNET);
 	//	setStyle(KDEV3);
-	//setStyle(KONTQSBC);
+	//setStyle(KONQSBC);
 	m_l->insertWidget(0,m_internal);
 	m_l->insertWidget(0,m_btnTabSep=new TQFrame(this));
 	m_btnTabSep->setFixedHeight(4);
diff --git a/kaffeine/src/kmultitabbar.h b/kaffeine/src/kmultitabbar.h
index 72fa884..2932cc2 100644
--- a/kaffeine/src/kmultitabbar.h
+++ b/kaffeine/src/kmultitabbar.h
@@ -55,16 +55,16 @@ class /*KUTILS_EXPORT*/ KMultiTabBar: public TQWidget
 	Q_OBJECT
   
 public:
-	enum KMultiTabBarMode{Horizontal,Vertical};
+	enum KMultiTabBarMode{Horizontal, Vertical};
 	enum KMultiTabBarPosition{Left, Right, Top, Bottom};
 
 	/**
 	 * VSNET == Visual Studio .Net like (only show the text of active tabs
 	 * KDEV3 == Kdevelop 3 like (always show the text)
-	 * KONTQSBC == konqy's classic sidebar style (unthemed), this one is disabled
+	 * KONQSBC == konqy's classic sidebar style (unthemed), this one is disabled
 	 * 	at the moment, but will be renabled soon too
 	 */
-	enum KMultiTabBarStyle{VSNET=0, KDEV3=1, KONTQSBC=2, KDEV3ICON=3,STYLELAST=0xffff};
+	enum KMultiTabBarStyle{VSNET=0, KDEV3=1, KONQSBC=2, KDEV3ICON=3,STYLELAST=0xffff};
 
 	KMultiTabBar(KMultiTabBarMode bm,TQWidget *parent=0,const char *name=0);
 	virtual ~KMultiTabBar();
diff --git a/kaffeine/src/player-parts/gstreamer-part/gstreamerconfig.cpp b/kaffeine/src/player-parts/gstreamer-part/gstreamerconfig.cpp
index ccb56f3..b7e88c7 100644
--- a/kaffeine/src/player-parts/gstreamer-part/gstreamerconfig.cpp
+++ b/kaffeine/src/player-parts/gstreamer-part/gstreamerconfig.cpp
@@ -54,7 +54,7 @@ GStreamerConfig::GStreamerConfig(const TQStringList& audioDrivers, const TQStrin
 	label = new TQLabel(i18n("Prefered audio driver"), frame);
 	layout->addWidget(label, 1, 0);
 	layout->addWidget(m_audioDriverBox, 1, 1);
-	layout->addMultiCellWidget(new KSeparator(Qt::Horizontal, frame), 2, 2, 0, 1);
+	layout->addMultiCellWidget(new KSeparator(KSeparator::Horizontal, frame), 2, 2, 0, 1);
 
 	//Video Page
 	frame = addPage(i18n("Video"), i18n("Video Options"), KGlobal::iconLoader()->loadIcon("video", KIcon::Panel,
@@ -67,7 +67,7 @@ GStreamerConfig::GStreamerConfig(const TQStringList& audioDrivers, const TQStrin
 	label = new TQLabel(i18n("Prefered video driver")+ "*", frame);
 	layout->addWidget(label, 1, 0);
 	layout->addWidget(m_videoDriverBox, 1, 1);
-	layout->addMultiCellWidget(new KSeparator(Qt::Horizontal, frame), 2, 2, 0, 1);
+	layout->addMultiCellWidget(new KSeparator(KSeparator::Horizontal, frame), 2, 2, 0, 1);
 	layout->addWidget(new TQLabel(TQString("<small>") + i18n("* Restart required!") + "</small>", frame), 10, 1);
 
 	//Media page
@@ -80,7 +80,7 @@ GStreamerConfig::GStreamerConfig(const TQStringList& audioDrivers, const TQStrin
 	label = new TQLabel(i18n("CD, VCD, DVD drive"), frame);
 	layout->addWidget(label, 1, 0);
 	layout->addWidget(m_driveEdit, 1, 1);
-	layout->addMultiCellWidget(new KSeparator(Qt::Horizontal, frame), 2, 2, 0, 1);
+	layout->addMultiCellWidget(new KSeparator(KSeparator::Horizontal, frame), 2, 2, 0, 1);
 }
 
 GStreamerConfig::~GStreamerConfig()
diff --git a/kaffeine/src/player-parts/xine-part/positionslider.cpp b/kaffeine/src/player-parts/xine-part/positionslider.cpp
index 16b3978..9d64e26 100644
--- a/kaffeine/src/player-parts/xine-part/positionslider.cpp
+++ b/kaffeine/src/player-parts/xine-part/positionslider.cpp
@@ -97,8 +97,8 @@ bool PositionSlider::eventFilter(TQObject *obj, TQEvent *ev)
 			return false;
 
 		int range = maxValue() - minValue();
-		int pos = (orientation() ==Qt::Horizontal) ? e->pos().x() : e->pos().y();
-		int maxpos = (orientation() ==Qt::Horizontal) ? width() : height();
+		int pos = (orientation() == Horizontal) ? e->pos().x() : e->pos().y();
+		int maxpos = (orientation() == Horizontal) ? width() : height();
 		int value = pos * range / maxpos + minValue();
 
 		if (TQApplication::reverseLayout())
diff --git a/kaffeine/src/player-parts/xine-part/postfilter.cpp b/kaffeine/src/player-parts/xine-part/postfilter.cpp
index 8a691b8..4ed3eb6 100644
--- a/kaffeine/src/player-parts/xine-part/postfilter.cpp
+++ b/kaffeine/src/player-parts/xine-part/postfilter.cpp
@@ -153,7 +153,7 @@ PostFilter::PostFilter(const TQString& name, xine_t* engine, xine_audio_port_t*
         m_xinePostParameter++;
       }
     }
-    KSeparator* sep = new KSeparator(Qt::Horizontal, m_groupBox);
+    KSeparator* sep = new KSeparator(KSeparator::Horizontal, m_groupBox);
     grid->addMultiCellWidget(sep, row, row, 0, 1);
     row++;
     KPushButton* deleteButton = new KPushButton(i18n("Delete Filter"), m_groupBox);
diff --git a/kaffeine/src/player-parts/xine-part/xine_part.cpp b/kaffeine/src/player-parts/xine-part/xine_part.cpp
index 98ff969..9fc18e6 100644
--- a/kaffeine/src/player-parts/xine-part/xine_part.cpp
+++ b/kaffeine/src/player-parts/xine-part/xine_part.cpp
@@ -1373,10 +1373,10 @@ void XinePart::initActions()
 	KStdAction::zoomIn(TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomIn()), actionCollection(), "zoom_in");
 	KStdAction::zoomOut(TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOut()), actionCollection(), "zoom_out");
 	KStdAction::fitToPage(TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOff()), actionCollection(), "zoom_off");
-	new KAction(i18n("Zoom InQt::Horizontal"), NULL, CTRL|Key_H, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomInX()), actionCollection(), "zoom_in_x");
-	new KAction(i18n("Zoom OutQt::Horizontal"), NULL, CTRL|SHIFT|Key_H, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOutX()), actionCollection(), "zoom_out_x");
-	new KAction(i18n("Zoom InQt::Vertical"), NULL, CTRL|Key_V, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomInY()), actionCollection(), "zoom_in_y");
-	new KAction(i18n("Zoom OutQt::Vertical"), NULL, CTRL|SHIFT|Key_V, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOutY()), actionCollection(), "zoom_out_y");
+	new KAction(i18n("Zoom In Horizontal"), NULL, CTRL|Key_H, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomInX()), actionCollection(), "zoom_in_x");
+	new KAction(i18n("Zoom Out Horizontal"), NULL, CTRL|SHIFT|Key_H, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOutX()), actionCollection(), "zoom_out_x");
+	new KAction(i18n("Zoom In Vertical"), NULL, CTRL|Key_V, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomInY()), actionCollection(), "zoom_in_y");
+	new KAction(i18n("Zoom Out Vertical"), NULL, CTRL|SHIFT|Key_V, TQT_TQOBJECT(m_xine), TQT_SLOT(slotZoomOutY()), actionCollection(), "zoom_out_y");
 	new KAction(i18n("Deinterlace &Quality"), "blend", CTRL|Key_I, TQT_TQOBJECT(this), TQT_SLOT(slotDeinterlaceQuality()), actionCollection(), "video_deinterlace_quality");
 	new KAction(i18n("&Video Settings"), "configure", Key_V, TQT_TQOBJECT(this), TQT_SLOT(slotPictureSettings()), actionCollection(), "video_picture");
 	new KAction(i18n("&Equalizer"), NULL, Key_E, TQT_TQOBJECT(this), TQT_SLOT(slotEqualizer()), actionCollection(), "equalizer");
@@ -1423,7 +1423,7 @@ void XinePart::initActions()
 	connect(m_xine, TQT_SIGNAL(signalSyncVolume()), TQT_TQOBJECT(this), TQT_SLOT(slotSyncVolume()));
 	new KWidgetAction(m_volume, i18n("Volume"), 0, 0, 0, actionCollection(), "audio_volume");
 
-	m_position = new PositionSlider(Qt::Horizontal);
+	m_position = new PositionSlider(Horizontal);
 	TQToolTip::add
 		(m_position, i18n("Position"));
 	m_position->setRange(0, 65535);
@@ -2061,7 +2061,7 @@ void XinePart::zoomOff()
 /********** volume slider ****************/
 
 
-VolumeSlider::VolumeSlider() : TQSlider(Qt::Horizontal, 0)
+VolumeSlider::VolumeSlider() : TQSlider(Horizontal, 0)
 {
 	installEventFilter(this);
 }
@@ -2092,8 +2092,8 @@ void VolumeSlider::wheelEvent(TQWheelEvent* e)
 			return FALSE;
 
 		int range = maxValue() - minValue();
-		int pos = (orientation() ==Qt::Horizontal) ? e->pos().x() : e->pos().y();
-		int maxpos = (orientation() ==Qt::Horizontal) ? width() : height();
+		int pos = (orientation() == Horizontal) ? e->pos().x() : e->pos().y();
+		int maxpos = (orientation() == Horizontal) ? width() : height();
 		int value = pos * range / maxpos + minValue();
 
 		if (TQApplication::reverseLayout())
diff --git a/kaffeine/src/player-parts/xine-part/xineconfig.cpp b/kaffeine/src/player-parts/xine-part/xineconfig.cpp
index 6d6a2d4..1281911 100644
--- a/kaffeine/src/player-parts/xine-part/xineconfig.cpp
+++ b/kaffeine/src/player-parts/xine-part/xineconfig.cpp
@@ -135,7 +135,7 @@ XineConfigEntry::XineConfigEntry(TQWidget* parent, TQGridLayout* grid, int row,
 	description->setAlignment( TQLabel::WordBreak | TQLabel::AlignVCenter );
 	grid->addWidget(description, row, 1);
 
-	KSeparator* separator = new KSeparator(Qt::Horizontal, parent);
+	KSeparator* separator = new KSeparator(KSeparator::Horizontal, parent);
 	grid->addMultiCellWidget(separator, row+1, row+1, 0, 1);
 }
 
diff --git a/kaffeine/src/systemtray.cpp b/kaffeine/src/systemtray.cpp
index 745360f..e781ba0 100644
--- a/kaffeine/src/systemtray.cpp
+++ b/kaffeine/src/systemtray.cpp
@@ -100,7 +100,7 @@ void SystemTray::mousePressEvent(TQMouseEvent *e)
 	default:
 		KSystemTray::mousePressEvent(e);
 		break;
-	case Qt::MidButton:
+	case MidButton:
 		if(!TQT_TQRECT_OBJECT(rect()).contains(e->pos()))
 			return;
 		actionCollection()->action("trayplay")->activate();
diff --git a/kaffeine/src/kaffeine.cpp b/kaffeine/src/kaffeine.cpp
index 2294956..6679b97 100644
--- a/kaffeine/src/kaffeine.cpp
+++ b/kaffeine/src/kaffeine.cpp
@@ -238,13 +238,13 @@ Kaffeine::Kaffeine() : DCOPObject("KaffeineIface"),
 	}
 #endif
 
 	/** KWin are you there? **/
 
 	m_haveKWin = KApplication::dcopClient()->isApplicationRegistered("twin");
 	if (m_haveKWin)
-		kdDebug() << "Window manager: KWin found" << endl;
+		kdDebug() << "Window manager: TWin found" << endl;
 	else
-		kdDebug() << "Window manager: not KWin - using save fullscreen mode" << endl;
+		kdDebug() << "Window manager: not TWin - using save fullscreen mode" << endl;
 
 	connect(&m_screensaverTimer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(slotFakeKeyEvent()));
 	m_screensaverTimer.start( 55000 );
@@ -1261,7 +1261,7 @@ void Kaffeine::mouseDoubleClickEvent(TQMouseEvent*)
 void Kaffeine::mousePressEvent(TQMouseEvent* mev)
 {
 	kdDebug() << "Kaffeine: Mouse press event" << endl;
-	if ( m_minimal->isChecked() && !m_fullscreen->isChecked() && (mev->button() == Qt::MidButton) ) {
+	if ( m_minimal->isChecked() && !m_fullscreen->isChecked() && (mev->button() == MidButton) ) {
 		if (topDock()->isVisible()) {
 			hideToolbars(true);
 			//menuBar()->hide;
@@ -238,13 +238,13 @@ Kaffeine::Kaffeine() : DCOPObject("KaffeineIface"),
 #endif
 
-	/** KWin are you there? **/
+	/** TWin are you there? **/
 
 	m_haveKWin = KApplication::dcopClient()->isApplicationRegistered("twin");